API documentation
=================

.. automodapi:: tessilator.tessilator
.. automodapi:: tessilator.lc_analysis
.. automodapi:: tessilator.contaminants
.. automodapi:: tessilator.makeplots
.. automodapi:: tessilator.maketable
.. automodapi:: tessilator.fixedconstants

